==> ephoto_dam-8.x-3.12.tar.gz: ephoto_dam/src/Plugin/CKEditorPlugin/EphotoDam.php <==
<?php

namespace Drupal\ephoto_dam\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\ckeditor\CKEditorPluginConfigurableInterface;
use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\Entity\Editor;

/**
 * Defines the plugin.
 *
 * @CKEditorPlugin(
 *   id = "ephoto_dam",
 *   label = @Translation("Ephoto Dam")
 * )
 */
class EphotoDam extends CKEditorPluginBase implements CKEditorPluginConfigurableInterface {

  /**
   * Default settings.
   *
   * @const
   */
  private const DEFAULT_SETTINGS = [
    'server_url' => '',
    'captions' => TRUE,
    'captions_format' => '',
    'zoom' => TRUE,
    'images_size' => 320,
    'videos_size' => 360,
    'documents_size' => 320,
  ];

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return drupal_get_path('module', 'ephoto_dam') . '/plugin/plugin.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return ['ephoto_dam' => $this->getSettings($editor)];
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'ephoto_dam' => [
        'label' => $this->t('Select a file from Ephoto Dam'),
        'image' => drupal_get_path('module', 'ephoto_dam') . '/plugin/icon.png',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state, Editor $editor) {
    $settings = (object) $this->getSettings($editor);

    $form['#attached']['library'][] = 'ephoto_dam/settings';

    $form['captions'] = [
      '#title' => $this->t('Captions'),
      '#type' => 'checkbox',
      '#default_value' => $settings->captions,
      '#description' => $this->t('Display the caption under images, videos and documents'),
      '#required' => FALSE,
    ];

    $form['captions_format'] = [
      '#title' => $this->t('Captions format'),
      '#type' => 'textarea',
      '#default_value' => $settings->captions_format,
      '#required' => FALSE,
    ];

    $form['zoom'] = [
      '#title' => $this->t('Zoom'),
      '#type' => 'checkbox',
      '#default_value' => $settings->zoom,
      '#description' => $this->t('View large images by clicking on them'),
      '#required' => FALSE,
    ];

    $form['images_size'] = [
      '#title' => $this->t('Images size'),
      '#type' => 'number',
      '#default_value' => $settings->images_size,
      '#description' => $this->t('Please enter the size of the images for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    $form['videos_size'] = [
      '#title' => $this->t('Videos size'),
      '#type' => 'number',
      '#default_value' => $settings->videos_size,
      '#description' => $this->t('Please enter the size of the videos for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    $form['documents_size'] = [
      '#title' => $this->t('Documents size'),
      '#type' => 'number',
      '#default_value' => $settings->documents_size,
      '#description' => $this->t('Please enter the size of the documents for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    return $form;
  }

  /**
   * Prepare the settings.
   *
   * @param object $editor
   *   The Editor.
   */
  protected function getSettings($editor):array {
    $editor_settings = $editor->getSettings();
    $common_settings = \Drupal::config('ephoto_dam.settings');

    $settings = NestedArray::getValue($editor_settings, [
      'plugins',
      'ephoto_dam',
    ]);

    if (!$settings) {
      $settings = self::DEFAULT_SETTINGS;
    }

    $server_url = $common_settings->get('server_url');

    if ($server_url) {
      $settings['server_url'] = $server_url;
    }

    return $settings;
  }

}

==> ephoto_dam-8.x-3.18.tar.gz: ephoto_dam/src/Plugin/CKEditorPlugin/EphotoDam.php <==
<?php

namespace Drupal\ephoto_dam\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\ckeditor\CKEditorPluginConfigurableInterface;
use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\FormStateInterface;
use Drupal\editor\Entity\Editor;

/**
 * Defines the plugin.
 *
 * @CKEditorPlugin(
 *   id = "ephoto_dam",
 *   label = @Translation("Ephoto Dam")
 * )
 */
class EphotoDam extends CKEditorPluginBase implements CKEditorPluginConfigurableInterface {

  /**
   * Default settings.
   */
  private const DEFAULT_SETTINGS = [
    'server_url' => '',
    'captions' => TRUE,
    'captions_format' => '',
    'zoom' => TRUE,
    'images_size' => 320,
    'videos_size' => 360,
    'documents_size' => 320,
  ];

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return \Drupal::service('extension.list.module')->getPath('ephoto_dam') . '/plugin/plugin.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return ['ephoto_dam' => $this->getSettings($editor)];
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'ephoto_dam' => [
        'label' => $this->t('Select a file from Ephoto Dam'),
        'image' => \Drupal::service('extension.list.module')->getPath('ephoto_dam') . '/plugin/icon.png',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state, Editor $editor) {
    $settings = (object) $this->getSettings($editor);

    $form['#attached']['library'][] = 'ephoto_dam/settings';

    $form['captions'] = [
      '#title' => $this->t('Captions'),
      '#type' => 'checkbox',
      '#default_value' => $settings->captions,
      '#description' => $this->t('Display the caption under images, videos and documents'),
      '#required' => FALSE,
    ];

    $form['captions_format'] = [
      '#title' => $this->t('Captions format'),
      '#type' => 'textarea',
      '#default_value' => $settings->captions_format,
      '#required' => FALSE,
    ];

    $form['zoom'] = [
      '#title' => $this->t('Zoom'),
      '#type' => 'checkbox',
      '#default_value' => $settings->zoom,
      '#description' => $this->t('View large images by clicking on them'),
      '#required' => FALSE,
    ];

    $form['images_size'] = [
      '#title' => $this->t('Images size'),
      '#type' => 'number',
      '#default_value' => $settings->images_size,
      '#description' => $this->t('Please enter the size of the images for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    $form['videos_size'] = [
      '#title' => $this->t('Videos size'),
      '#type' => 'number',
      '#default_value' => $settings->videos_size,
      '#description' => $this->t('Please enter the size of the videos for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    $form['documents_size'] = [
      '#title' => $this->t('Documents size'),
      '#type' => 'number',
      '#default_value' => $settings->documents_size,
      '#description' => $this->t('Please enter the size of the documents for the display'),
      '#required' => TRUE,
      '#field_suffix' => 'px',
      '#attributes' => ['min' => 0, 'max' => 6000],
      '#size' => 20,
    ];

    return $form;
  }

  /**
   * Returns the user settings for the CKEditor plugin. Apply default settings if necessary.
   * Also add "server_url" setting. This setting is common to the 2 modules ephoto_dam and ephoto_dam_field
   *
   * @param object $editor
   *   The Editor.
   *
   * @return array
   *   An array of settings.
   */
  protected function getSettings($editor):array {
    $editor_settings = $editor->getSettings();

    $settings = NestedArray::getValue($editor_settings, [
      'plugins',
      'ephoto_dam',
    ]);

    if (!$settings) {
      $settings = self::DEFAULT_SETTINGS;
    }

    $server_url = \Drupal::config('ephoto_dam.settings')->get('server_url');

    if ($server_url) {
      $settings['server_url'] = $server_url;
    }

    return $settings;
  }

}
